@@ -27,17 +27,17 @@ impl Dumper for Postgresql {
             _ => return,
         };
 
-        let row = client
-            .query_one(
+        let result = client
+            .query(
                 "select column_name from information_schema.columns where table_name = $1",
                 &[&options.table],
             )
             .expect("Query postgresql error");
 
         let mut name_row: Vec<String> = vec![];
-        for i in 0..row.len() {
-            name_row.push(row.get(i));
-        }
+        result.iter().for_each(|row| {
+            name_row.push(row.get(0));
+        });
         writer.write_row(name_row.clone());
 
         let mut sql = "select ".to_owned();
